#!/usr/bin/env python
# -*- coding: utf-8 -*-
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import ConfigParser
from optparse import OptionParser
from singleton import *
import os
import time
import sys

optParser = OptionParser()
optParser.add_option("-p", "--project", type="string", dest="project", help='')
optParser.add_option("-e", "--env", type="string", dest="env", help='')

CONF_FILE_PATH = './service_conf.ini'

@singleton
class __ServiceManager():
    def __init__(self):
        self.conf_file = CONF_FILE_PATH
        self.load()

    def load(self):
        self.cf = ConfigParser.ConfigParser()
        self.cf.read(self.conf_file)
        self.mtime = os.path.getmtime(self.conf_file)
        sys.stderr.write('load conf file at [%s]\n' % time.ctime(time.time()))

    def reload(self):
        if self.mtime != os.path.getmtime(self.conf_file):
            self.load()

    def get_ex(self, name, key, dft_val):
        self.reload()
        try:
            return self.cf.get(name, key)
        except Exception, e:
            print e
            return dft_val

    def get(self, name, key):
        self.reload()
        return self.cf.get(name, key)

    def has(self, name, key):
        return self.cf.has_option(name, key)


def GET_CONF_EX(name, key, dft_val):
    manager = __ServiceManager()
    return manager.get_ex(name, key, dft_val)


def GET_CONF(name, key):
    manager = __ServiceManager()
    return manager.get(name, key)


def HAS_CONF(name, key):
    manager = __ServiceManager()
    return manager.has(name, key)


def SET_CONF_FILE(conf_file):
    global CONF_FILE_PATH
    CONF_FILE_PATH = conf_file
    manager = __ServiceManager()

def main():
    print GET_CONF('hadoop', 'user_name')
    print GET_CONF('sentinel', 'hosts')


if __name__ == '__main__':
    main()




#!/usr/bin/env python
# -*- coding: utf-8 -*-

def singleton(cls, *args, **kw):
    instances = {}

    def _singleton():
        if cls not in instances:
            instances[cls] = cls(*args, **kw)
        return instances[cls]

    return _singleton


@singleton
class Car():
    def __init__(self):
        pass


def main():
    car = Car()
    print id(car)
    car = Car()
    print id(car)
    car = Car()
    print id(car)

if __name__ == '__main__':
    main()


import cat_helper
import time
import cat
from cat_helper import *


#@cat_helper.cat_wrapper('kd-test', 'hxa', 'wrapper2')
#def fun():
#    print '---------start------------'
#    time.sleep(3)
#    print '----------end-------------'
#    raise ValueError

#fun()

init('inke-test')
stage_begin('lh', 'test6')
#cat.Transaction('test1', 'test')
#cat.log_event('test', 'test1', '0')
time.sleep(2)
stage_begin('lh', 'test6')
time.sleep(2)
stage_end('lh', 'test6')
#stage_end('lh', 'test6', False)





# -*- coding:utf-8 -*-

import cat
import time
import traceback

from inkebase.log import *
from singleton import singleton


base_name = ""

def init(name):
    global base_name
    base_name = name

@singleton
class CatInit(object):
    def __init__(self):
        logger().info('cat init, base name [%s]', base_name)
        cat.init(base_name)

@singleton
class CatStage(object):
    def __init__(self):
        CatInit()
        self.__stage_map = {}

    def stage_begin(self, space, name):
        key = (space, name)
        logger().info('cat begin space[%s], name[%s]', space, name)
        self.__stage_map[key] = cat.Transaction(space, name)

    def stage_end(self, space, name, status):
        key = (space, name)
        assert key in self.__stage_map
        if not status:
            self.__stage_map[key].set_status(cat.CAT_ERROR)
            cat.log_event(space, name, cat.CAT_ERROR)
        else:
            cat.log_event(space, name, cat.CAT_SUCCESS)

        logger().info('cat complete space[%s], name[%s], status[%s]', 
                space, name, status)
        self.__stage_map[key].complete()
        del self.__stage_map[key]

@singleton
class CatStageAgency(object):
    def __init__(self):
        CatInit()
        self.reset()

    def reset(self):
        self.__stage_list = []

    def stage_begin(self, space, name):
        key = (space, name)
        name = '%s/%s' % (space, name)
        tran = cat.Transaction(space, name)
        self.__stage_list.append(tran)

    def finish(self):
        if len(self.__stage_list) > 0:
            logger().info('cat finish, flush %d transactions',
                          len(self.__stage_list))
        for val in self.__stage_list[::-1]:
            val.complete()
        self.__stage_list = []

def cat_wrapper(appkey, space, name):
    def decorator(func):
        def wrapper(*args, **kw):
            try:
                init(appkey)
                stage_begin(space, name)
                f = func(*args, **kw)
                flag = True
                if f == False:
                    flag = False
                stage_end(space, name, flag)
                return f
            except Exception as e:
                stage_end(space, name, False)
                raise
        return wrapper
    return decorator


#----------------Shortcut--------------

def stage_begin(space, name):
    try:
        CatStage().stage_begin(space, name)
    except Exception as e:
        err_msg = traceback.format_exc()
        logger().error('cat error:' + err_msg)

def stage_end(space, name, status=True):
    try:
        CatStage().stage_end(space, name, status)
    except Exception as e:
        err_msg = traceback.format_exc()
        logger().error('cat error:' + err_msg)

def agent_stage_begin(space, name):
    try:
        CatStageAgency().stage_begin(space, name)
    except Exception as e:
        err_msg = traceback.format_exc()
        logger().error('cat error:' + err_msg)

def agent_reset():
    try:
        CatStageAgency().reset()
    except Exception as e:
        err_msg = traceback.format_exc()
        logger().error('cat error:' + err_msg)

def agent_finish():
    try:
        CatStageAgency().finish()
    except Exception as e:
        err_msg = traceback.format_exc()
        logger().error('cat error:' + err_msg)

def log_event(space, name):
    try:
        name = '%s/%s' % (space, name)
        cat.log_event(space, name)
    except Exception as e:
        err_msg = traceback.format_exc()
        logger().error('cat error:' + err_msg)

def test():
    import time
    stage_begin('a', '3')
    stage_begin('a', '4')
    time.sleep(1)
    stage_end('a', '4')
    stage_end('a', '3')

def test2():
    import time
    init('kd.base123')
    agent_stage_begin('b', 'b')
    agent_stage_begin('b', 'c')
    agent_stage_begin('b', 'd')
    time.sleep(1)
    agent_finish()

def test1():
    import time
    cat.init("kd.test")
    a = cat.Transaction('c', 'b')
    time.sleep(2)
    a.complete()
    b = cat.Transaction('c', 'c')
    time.sleep(2)
    b.complete()

def main():
    test2()

if __name__ == '__main__':
    main()







#!/bin/env python
#-*- coding:utf-8 -*-

import json
import time
import socket
import requests

def dingding(access_token, content):
    '''
    推送方式：dingding
    '''
    headers = {'Content-Type': 'application/json;charset=utf-8'}
    url = "https://oapi.dingtalk.com/robot/send?access_token=%s" % (access_token)
    msgtype = 'text'
    values = {
        "msgtype": 'text',
        'text': {
            "content": content
        }
    }
    values = json.dumps(values)
    data = requests.post(url, values,headers=headers)
    errmsg = json.loads(data.text)['errmsg']
    if errmsg == 'ok':
        return "ok"
    return "fail: %s" % data.text


def falcon(metric, value, tag, ctype='GAUGE', step=60, lo_host=socket.gethostname()):
    '''
    推送方式：falcon
    '''
    payload = []
    ts = int(time.time())
    falcon_url = 'http://127.0.0.1:1988/v1/push'
    falcon_dic = {
        "endpoint": lo_host,
        "metric": metric,
        "timestamp": ts,
        "step": step,
        "value": int(value),
        "counterType": ctype,
        "tags": tag
    }
    payload.append(falcon_dic)
    header = {'content-type': "application/json"}
    if len(payload) > 0:
        t = requests.post(falcon_url, data = json.dumps(payload))

if __name__ == '__main__':
    pass





# -*- coding: utf-8 -*-


import os
import unittest

case_path = '.' 

def all_cases():
    discover = unittest.defaultTestLoader.discover(case_path, 
            pattern='test_*.py', top_level_dir=None)
    for case in discover:
        print 'CASE: %s' % case
    print '\n'
    return discover


if __name__ == '__main__':
    print '--------------- RUN UNIT TEST CASES ----------------'
    runner = unittest.TextTestRunner()
    runner.run(all_cases())



# -*- coding:utf-8 -*-

import logging
import os
import shutil
import time
import sys

initialized = False
formatter = logging.Formatter('%(asctime)s %(levelname)s %(process)d' '[%(filename)s:%(lineno)d %(funcName)s]: %(message)s')


class Configer():
    def __init__(self):
        self.__log_path = ""
        self.__file_handler = None
        self.__console_handler = None
        self.__pure_path = "./log.txt"
        self.__time_format = "%Y%m%d%H%M"
        self.__time_format = "%Y%m%d"

    inst = None

    @staticmethod
    def get():
        if Configer.inst == None:
            Configer.inst = Configer()
        return Configer.inst

    def set_file_handler(self):
        date_str = time.strftime(self.__time_format)
        self.__log_path = self.__pure_path + '.' + date_str

        fh = logging.FileHandler(self.__log_path)
        fh.setFormatter(formatter)
        self.__file_handler = fh
        logging.getLogger('').addHandler(fh)

    def set_console_handler(self):
        console = logging.StreamHandler()
        console.setLevel(logging.DEBUG)
        console.setFormatter(formatter)
        self.__console_handler = console
        logging.getLogger('').addHandler(console)
        logging.getLogger('').setLevel(logging.INFO)

    def del_console_handler(self):
        logging.getLogger('').removeHandler(self.__console_handler)
        del self.__console_handler
        self.__console_handler = None

    def del_file_handler(self):
        logging.getLogger('').removeHandler(self.__file_handler)
        del self.__file_handler
        self.__file_handler = None

    def rotate(self):
        date_str = time.strftime(self.__time_format)
        path = self.__pure_path + '.' + date_str
        self.__log_path

        if path == self.__log_path:
            return
        sys.stdout.flush()
        sys.stderr.flush()
        self.del_file_handler()
        self.set_file_handler()

    def init(self, level, path="./log.txt", quiet=False):
        self.__pure_path = path
        if quiet:
            self.del_console_handler()

        if not quiet and not self.__console_handler:
            self.set_console_handler()
        self.set_file_handler()

        cmd = str("logging.getLogger("").setLevel(logging.%s)" % (level.upper()))
        exec cmd


class Logger():
    def __init__(self):
        self.info = logging.info
        self.debug = logging.debug
        self.warning = logging.warning
        self.error = logging.error
        self.critical = logging.critical
        Configer.get().set_console_handler()


def log_init(level, path="./log.txt", quiet = True):
    global initialized
    if initialized: return
    Configer.get().init(level, path, quiet)
    initialized = True


g_logger = Logger()


def logger():
    Configer.get().rotate()
    return g_logger

def log(log_dir, log_level='info', quiet=False):
    def decorator(func):
        def wrapper(*args, **kw):
            global initialized
            initialized = False 
            log_init(log_level, log_dir, quiet=quiet)
            return func(*args, **kw)
        return wrapper
    return decorator



if __name__ == '__main__':
    log_init('info', './log.txt', quiet=False)
    while True:
        l = logger()
        l.info('abc')
        time.sleep(1)




# -*- coding:utf-8 -*-
import os
import base64
import hashlib
import json
import time
import math

def ceil(f):
    return int(math.ceil(f))

def human_info(data):
    if type(data) == dict: # pylint: disable=C0123
        ret = '{'
        for k, v in data.items():
            ret += str("%s:%s, " % (human_info(k), human_info(v)))
        ret += '}'

    elif type(data) == list: # pylint: disable=C0123
        ret = '['
        for i in range(len(data)):
            ret += '%s,' % human_info(data[i])
        ret += ']'

    elif type(data) == tuple: # pylint: disable=C0123
        ret = '('
        for i in range(len(data)):
            ret += '%s,' % human_info(data[i])
        ret += ')'

    elif type(data) == unicode: # pylint: disable=C0123
        ret = data.encode('utf-8')
        ret = str("'%s'" % ret)
    elif type(data) == str: # pylint: disable=C0123
        ret = str("'%s'" % data)
    else:
        ret = str(data)

    return ret


def get_val_ex(_dict, _key, dft_val):
    if _key not in _dict:
        return dft_val
    else:
        return _dict[_key]

def get_hour_delta(time_str):
    ts = time.mktime(time.strptime(time_str, '%Y-%m-%d %H:%M:%S'))
    now = time.time()
    return (now - ts) / 3600

def json_read(jdata):
    return transcode(json.loads(jdata))

def json_write(data):
    return json.dumps(data)

def filter_id(data_list):
    for d in data_list:
        del d['_id']
    return data_list

def get_md5(src):
    myMd5 = hashlib.md5()
    myMd5.update(src)
    myMd5_Digest = myMd5.hexdigest()
    return myMd5_Digest

def file_md5(path):
    src = open(path).read()
    return get_md5(path)


def get_suffix(filename):
    segs = os.path.split(filename)
    return os.path.splitext(segs[1])[1]

def transcode(data):
    if type(data) == dict: # pylint: disable=C0123
        for k, v in data.items():
            del data[k]
            data[transcode(k)] = transcode(v)

    elif type(data) == list: # pylint: disable=C0123
        for i in range(len(data)):
            data[i] = transcode(data[i])

    elif type(data) == unicode: # pylint: disable=C0123
        data = data.encode('utf-8')

    return data

def encode_name(name):
    seg = name.split('-')
    seg[1] = base64.b64encode(seg[1])
    name = seg[0] + '-' + seg[1]
    return name

def decode_name(name):
    seg = name.split('-')
    seg[1] = base64.b64decode(seg[1])
    name = seg[0] + '-' + seg[1]
    return name

def separate_file_name(file_name):
    try:
        idx = file_name.index('.')
        part1 = file_name[:idx]
        image_type = file_name[idx+1:]

        idx = part1.rindex('_')
        seq = part1[idx+1:]
        part1 = part1[:idx]

        idx = part1.rindex('_')
        tpe = part1[idx+1:]
        tpid = part1[:idx]
        return tpid, tpe, seq, image_type
    except Exception, e: # pylint: disable=W0703
        return None


_file_type_dict = {}
_file_type_dict['png'] = 'image/png'
_file_type_dict['webp'] = 'image/webp'
_file_type_dict['jpg'] = 'image/jpeg'
_file_type_dict['jpeg'] = 'image/jpeg'
_file_type_dict['jpe'] = 'image/jpeg'
_file_type_dict['gz'] = 'application/x-gzip'
_file_type_dict['txt'] = 'text/plain'
_file_type_dict['pb'] = 'application/octet-stream'

def filetype_valid(file_type):
    return file_type in _file_type_dict

def filetype2contenttype(file_type):
    if file_type in _file_type_dict:
        return _file_type_dict[file_type]
    else:
        return None

def str_to_bool(string):
    return string.lower() == 'true'

def bool_to_str(boolean):
    return 'True' if boolean else 'False'

def main():
    print separate_file_name('114_20170621133647894_00_003.jpg')
    print separate_file_name('129_20170621132818068_02_000.yml.gz')

    NEED_DATA = {'kafka.coordinator.group.GroupMetadataManager': ['NumGroups', 'NumOffsets'], 'kafka.server.BrokerTopicMetrics': ['MessagesInPerSec', 'BytesOutPerSec', 'BytesInPerSec', 'TotalFetchRequestsPerSec', 'FailedFetchRequestsPerSec', 'FailedProduceRequestsPerSec', 'ReplicationBytesInPerSec', 'BytesRejectedPerSec', 'TotalProduceRequestsPerSec', 'ReplicationBytesOutPerSec'], 'kafka.server.ReplicaManager': ['UnderReplicatedPartitions', 'LeaderCount', 'PartitionCount', 'IsrShrinksPerSec', 'FailedIsrUpdatesPerSec', 'IsrExpandsPerSec'], 'kafka.server.ReplicaFetcherManager.clientId.Replica': ['MaxLag', 'MinFetchRate'], 'kafka.network.RequestChannel': ['ResponseQueueSize', 'RequestQueueSize'], 'kafka.server.DelayedOperationPurgatory.delayedOperation.txn-marker-purgatory': ['NumDelayedOperations', 'PurgatorySize'], 'kafka.network.RequestMetrics.error.UNKNOWN_SERVER_ERROR.request.Fetch':['ErrorsPerSec'], 'kafka.network.RequestMetrics.error.UNKNOWN_SERVER_ERROR.request.Produce':['ErrorsPerSec'], 'kafka.network.RequestMetrics.error.UNKNOWN_TOPIC_OR_PARTITION.request.Fetch':['ErrorsPerSec'], 'kafka.network.RequestMetrics.error.UNKNOWN_TOPIC_OR_PARTITION.request.Metadata':['ErrorsPerSec']}
    print transcode(NEED_DATA)

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

import json
from inkebase.log import *
import StringIO
import gzip

def SUCCESS(result):
    ret = {}
    ret['code'] = 0
    ret['message'] = 'success'
    ret['result'] = result
    return json.dumps(ret)

def SUCCESS_GZIP(result):
    return gzip_compress(SUCCESS(result))

def gzip_compress(buf):
    out = StringIO.StringIO()
    with gzip.GzipFile(fileobj=out, mode="w") as f:
        f.write(buf)
    return out.getvalue()

def FAIL(code, msg):
    logger().error(msg)
    ret = {}
    ret['code'] = code
    ret['message'] = msg
    return json.dumps(ret)

if __name__ == '__main__':
    FAIL(1001, 'hadoop资源不足')




import multiprocessing
import time
import os

def func(who='1'):
    print "user:", who
    time.sleep(1)
    print "end"
    return "done " + who

class WorkerPool(object):
    def __init__(self, worker_num):
        self.__pool = multiprocessing.Pool(processes=worker_num)
        self.__results = []

    def push(self, func, args):
        self.__results.append(self.__pool.apply_async(func, args))
        

    def wait_until_finish(self):
        self.__pool.close()
        self.__pool.join()
        
    def get_results(self):
        return self.__results

def main():
    pool = WorkerPool(4)
    for i in xrange(10):
        who = "user %d" % (i)
        pool.push(func, (who, ))
        print 'pid:%d' % os.getpid()
    time.sleep(10)
    pool.wait_until_finish()
    print pool.get_results()
    for res in pool.get_results():
        print ":::", res.get()
    print "all process(es) done."

if __name__ == "__main__":
    main()




from optparse import OptionParser

parser = OptionParser()
add_option = parser.add_option
options = None
args = None
argv = None

def set_opt_local():
    global argv # pylint: disable=W0603
    argv = []

def option():
    global options # pylint: disable=W0603
    global args # pylint: disable=W0603
    if not options:
        (options, args) = parser.parse_args(argv)
    return options

DEFINE_FLAG = add_option
FLAG = option

DEFINE_FLAG("-m", "--my_flag",
            action = "store_true",
            dest = "my_flag", default = False,
            help = "Whether to show tag-itemlist")

def main():
    print option().my_flag


if __name__ == '__main__':
    main()



#-*- coding:utf-8 -*-
import os
import time
import sys

if __name__ == '__main__':
    for i in range(0, 10):
        time.sleep(i)
        #logger().info('第%d次:子进程id: %d' % (i, os.getpid()))
        print '第%d次:子进程id: %d' % (i, os.getpid())
        print '第%d次:子进程id: %d' % (i, os.getpid())
        #sys.stdout.flush()
        if i%2 == 0:
            sys.stderr.write('第%d次error\n' % (i))
    #time.sleep(30)
    sys.stderr.write('第%d次error\n' % (i))
        #print time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time()))
        #sys.stderr.flush()
        



#!/usr/bin/env python
#-*-coding: utf-8 -*-

import unittest
import sys

sys.path.append('..')
from opt import *


class TestOpt(unittest.TestCase):
    
    def test_option(self):
        res = option()
        self.assertIsNotNone(res)

   
if __name__ == '__main__':
    unittest.main()



import os
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="inkebase", 
    version="1.6.0",                       
    author="inke-bigdata",              
    author_email="majiankun@inke.cn",    
    description="Common tools", 
    long_description=long_description,              
    long_description_content_type="text/markdown",  
    packages=setuptools.find_packages(),    
    classifiers=[                    
        "Programming Language :: Python :: 2",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)



#!/usr/bin/env python


import time

class Timer():
    def __init__(self):
        self.stages = []

    def reset(self):
        self.stages = []
        

    def stage_begin(self, name):
        if self.stages:
            last = self.stages[-1]
            if len(last) < 3:
                last.append(time.time())

        new = [name, time.time()]
        self.stages.append(new)
        

    def stage_end(self, name):
        if self.stages:
            last = self.stages[-1]
            if len(last) < 3:
                last.append(time.time())

    def finish(self):
        if self.stages:
            last = self.stages[-1]
            if len(last) < 3:
                last.append(time.time())

    def dump(self):
        msg = ''
        
        total = 0.
        for stage in self.stages:
            dura = 1000 * (stage[2] - stage[1])
            name = stage[0]
            msg += str('[%s:%.1f]' % (name, dura))
            total += dura

        msg = 'total[%.1fms] ' % total + msg
        return msg

def main():
    _timer = Timer()
    _timer.stage_begin('stage1')
    time.sleep(0.5)
    _timer.stage_end('stage1')

    _timer.stage_begin('stage2')
    time.sleep(0.4)
    _timer.stage_begin('stage3')
    time.sleep(0.3)
    _timer.stage_begin('stage4')
    time.sleep(0.2)

    _timer.finish()

    print _timer.dump()


if __name__ == '__main__':
    main()
